


# Goodman Focus Finder

![Goodman Focus](https://github.com/soar-telescope/goodman_focus/workflows/Goodman%20Focus/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/soar-telescope/goodman_focus/badge.svg?branch=master)](https://coveralls.io/github/soar-telescope/goodman_focus?branch=master)
[![Documentation Status](https://readthedocs.org/projects/goodman-focus/badge/?version=latest)](https://goodman-focus.readthedocs.io/en/latest/?badge=latest)
[![pypi](https://img.shields.io/pypi/v/goodman_focus.svg?style=flat)](https://pypi.org/project/goodman-focus/)

Finds the best focus for one or more focus sequences.

# Documentation

All the documentation is maintained in https://soardocs.readthedocs.io/projects/focus/en/latest/

# Found a problem?

Please [Open an Issue](https://github.com/soar-telescope/goodman_focus/issues) on
GitHub.